Module key

Module key 

Core traits and types for PASETO keys.

Structs

Key
Generic key type.

Traits

HasKey
Declares that this PASETO implementation supports the given key type, as well as how to encode/decode the key.
KeyType
A marker for Secret, Public, and Local
SealingKey
A marker for Secret and Local keys, used for signing and encrypting tokens.