Key

Struct Key 

pub struct Key<V: HasKey<K>, K: KeyType>(/* private fields */);
Generic key type.

Implementations

Source

impl<V: SealingVersion<Public>> Key<V, Secret>

pub fn random() -> Result<Self, PasetoError>

Generate a random secret key

pub fn public_key(&self) -> PublicKey<V>

Derive the associated public key

Source

impl<V: SealingVersion<Local>> Key<V, Local>

pub fn random() -> Result<Self, PasetoError>

Generate a random local key

Source

impl<V: IdVersion + HasKey<K>, K: KeyType> Key<V, K>

pub fn id(&self) -> KeyId<V, K>

Generate the ID of this key

Source

impl<V: PieWrapVersion + HasKey<K>, K: SealingKey> Key<V, K>

pub fn wrap_pie( self, with: &LocalKey<V>, ) -> Result<PieWrappedKey<V, K>, PasetoError>

Source

impl<V: PkeSealingVersion> Key<V, Local>

pub fn seal(self, with: &Key<V, PkePublic>) -> Result<SealedKey<V>, PasetoError>

Encrypt the key such that it can only be decrypted by the resspective secret key.

Source

impl<V: HasKey<K>, K: KeyType> Key<V, K>

pub fn expose_key(&self) -> KeyText<V, K>

Expose the key data such that it can be serialized.

Be advised that serializing key data can be dangerous. Make sure they are saved on secure disks or sent on secure connections only.

Source

impl<V: PwWrapVersion + HasKey<K>, K: SealingKey> Key<V, K>

pub fn password_wrap( self, pass: &[u8], ) -> Result<PasswordWrappedKey<V, K>, PasetoError>

Encrypt the key using the password.

pub fn password_wrap_with_params( self, pass: &[u8], params: &V::Params, ) -> Result<PasswordWrappedKey<V, K>, PasetoError>

Encrypt the key using the password, configured with the specified parameters.