pub struct KeyText<V: Version, K: KeyType> { /* private fields */ }Expand description
A plaintext encoding of a key.
Be advised that this encoding has no extra security, so it is not safe to transport as is.
Implementations