Module version

Module version 

Various helper traits

Structs

Local
Marks a key as symmetric and tokens as encrypted
PkePublic
Marks a key as public for sealing keys
PkeSecret
Marks a key as secret for unsealing keys
Public
Marks a key as public and tokens as signed
Secret
Marks a key as secret

Traits

Purpose
A marker for Public and Local, used for token encodings.
SealingVersion
This PASETO implementation can sign/encrypt tokens.
UnsealingVersion
This PASETO implementation can decrypt/verify tokens.
Version
An implementation of the PASETO cryptographic schemes.